@@ -3,12 +3,14 @@
 {
     'name': 'Stock Management',
     'name_bg_BG': 'Управление на наличности',
+    'name_ca_ES': 'Estocs',
     'name_de_DE': 'Lagerverwaltung',
+    'name_es_AR': 'Gestión de existencias',
     'name_es_CO': 'Inventarios',
-    'name_es_ES': 'Gestión de existencias',
+    'name_es_ES': 'Stocks',
     'name_fr_FR': 'Gestion des stocks',
     'name_ru_RU': 'Управление складами',
-    'version': '2.2.1',
+    'version': '2.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -35,6 +37,18 @@ And with reports:
     - Опаковъчен лист
     - Преизчисляване на инвентарен опис (при пратка на доставчик и пратка върната от клиент)
     - Продукти по местонахождение
+''',
+    'description_ca_ES': '''Gestió d'estocs i control d'inventaris amb:
+    - Definició d'ubicacions
+    - Moviments d'estoc
+    - Albarans de proveïdors, clients i interns. Albarans de devolució a client i proveïdor.
+    - Inventaris d'estoc
+
+Amb informes:
+    - Albarà de lliurament
+    - Albarà intern o de picking
+    - Llista de recàlcul d'estocs (en recepcions de proveïdors i de devolucions de clients)
+    - Productes per ubiació
 ''',
     'description_de_DE': '''Lagerverwaltung und Bestandskontrolle mit:
     - Definition von Lagerorten
@@ -48,17 +62,7 @@ Mit den Berichten:
     - Einlagerungsliste (für Lieferposten von Lieferanten und Warenrücknahmen)
     - Artikel nach Lagerorten
 ''',
-    'description_es_CO': '''Administración de Inventarios y bodegas:
-    - Definición de sitios
-    - Movimiento de Bodega
-    - Empaque de Proveedor / Cliente / Interno
-    - Inventario en Bodega
-
-Y con los reportes:
-    - Empaques de Clientes
-    - Productos por Lugar
-''',
-    'description_es_ES': '''Gestión de Existencias y control de inventarios con:
+    'description_es_AR': '''Gestión de Existencias y control de inventarios con:
     - Definición de ubicaciones
     - Movimiento de existencias
     - Envios de proveedores, clientes e internos. Envio de devoluciones de clientes y proveedores.
@@ -70,7 +74,29 @@ Y con los informes:
     - Lista de recálculo de existencias (con envios de proveedores y envios de devoluciones de clientes)
     - Productos por ubicación
 ''',
-    'description_fr_FR':'''Gestion des stocks et contrôle de l'inventaire avec:
+    'description_es_CO': '''Administración de Inventarios y bodegas:
+    - Definición de sitios
+    - Movimiento de Bodega
+    - Empaque de Proveedor / Cliente / Interno
+    - Inventario en Bodega
+
+Y con los reportes:
+    - Empaques de Clientes
+    - Productos por Lugar
+''',
+    'description_es_ES': '''Gestión de stocks y control de inventarios con:
+    - Definición de ubicaciones
+    - Movimientos de stock
+    - Albaranes de proveedores, clientes e internos. Albaranes de devolución de clientes y proveedores.
+    - Inventario de stock
+
+Y con los informes:
+    - Albarán de entrega
+    - Albarán interno o de picking
+    - Lista de recálculo de stocks (en recepciones de proveedores y devoluciones de clientes)
+    - Productos por ubicación
+''',
+    'description_fr_FR': '''Gestion des stocks et contrôle de l'inventaire avec:
     - Emplacement
     - Mouvement de stock
     - Expédition client, fournisseur et interne. Retour d'expédition client et founisseur.
@@ -96,7 +122,6 @@ Et les rapports:
 ''',
     'depends': [
         'ir',
-        'workflow',
         'party',
         'product',
         'company',
@@ -116,7 +141,9 @@ Et les rapports:
     'translation': [
         'locale/cs_CZ.po',
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
