@@ -1,8 +1,9 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 import datetime
+from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.wizard import Wizard
+from trytond.wizard import Wizard, StateView, Button, StateAction
 from trytond.backend import TableHandler
 from trytond.pyson import Not, Bool, Eval, Equal, PYSONEncoder, Date
 from trytond.transaction import Transaction
@@ -21,8 +22,8 @@ class Location(ModelSQL, ModelView):
     name = fields.Char("Name", size=None, required=True, states=STATES,
         depends=DEPENDS, translate=True)
     code = fields.Char("Code", size=None, states=STATES, depends=DEPENDS,
-        select=1)
-    active = fields.Boolean('Active', select=1)
+        select=True)
+    active = fields.Boolean('Active', select=True)
     address = fields.Many2One("party.address", "Address",
         states={
             'invisible': Not(Equal(Eval('type'), 'warehouse')),
@@ -38,10 +39,10 @@ class Location(ModelSQL, ModelView):
         ('production', 'Production'),
         ('view', 'View'),
         ], 'Location type', states=STATES, depends=DEPENDS)
-    parent = fields.Many2One("stock.location", "Parent", select=1,
+    parent = fields.Many2One("stock.location", "Parent", select=True,
             left="left", right="right")
-    left = fields.Integer('Left', required=True, select=1)
-    right = fields.Integer('Right', required=True, select=1)
+    left = fields.Integer('Left', required=True, select=True)
+    right = fields.Integer('Right', required=True, select=True)
     childs = fields.One2Many("stock.location", "parent", "Children")
     input_location = fields.Many2One(
         "stock.location", "Input", states={
@@ -50,10 +51,10 @@ class Location(ModelSQL, ModelView):
             'required': Equal(Eval('type'), 'warehouse'),
             },
         domain=[
-            ('type','=','storage'),
+            ('type', '=', 'storage'),
             ['OR',
                 ('parent', 'child_of', [Eval('id')]),
-                ('parent', '=', False),
+                ('parent', '=', None),
                 ],
             ],
         depends=['type', 'active', 'id'])
@@ -63,10 +64,11 @@ class Location(ModelSQL, ModelView):
             'readonly': Not(Bool(Eval('active'))),
             'required': Equal(Eval('type'), 'warehouse'),
         },
-        domain=[('type','=','storage'),
+        domain=[
+            ('type', '=', 'storage'),
             ['OR',
                 ('parent', 'child_of', [Eval('id')]),
-                ('parent', '=', False)]],
+                ('parent', '=', None)]],
         depends=['type', 'active', 'id'])
     storage_location = fields.Many2One(
         "stock.location", "Storage", states={
@@ -74,14 +76,17 @@ class Location(ModelSQL, ModelView):
             'readonly': Not(Bool(Eval('active'))),
             'required': Equal(Eval('type'), 'warehouse'),
         },
-        domain=[('type','=','storage'),
+        domain=[
+            ('type', '=', 'storage'),
             ['OR',
                 ('parent', 'child_of', [Eval('id')]),
-                ('parent', '=', False)]],
+                ('parent', '=', None)]],
         depends=['type', 'active', 'id'])
     quantity = fields.Function(fields.Float('Quantity'), 'get_quantity')
     forecast_quantity = fields.Function(fields.Float('Forecast Quantity'),
             'get_quantity')
+    cost_value = fields.Function(fields.Numeric('Cost Value'),
+        'get_cost_value')
 
     def __init__(self):
         super(Location, self).__init__()
@@ -94,7 +99,8 @@ class Location(ModelSQL, ModelView):
             'recursive_locations': 'You can not create recursive locations!',
             'invalid_type_for_moves': 'A location with existing moves ' \
                 'cannot be changed to a type that does not support moves.',
-            'child_of_warehouse': 'Location "%s" must be a child of warehouse "%s"!',
+            'child_of_warehouse': 'Location "%s" must be a child of ' \
+                'warehouse "%s"!',
         })
 
     def init(self, module_name):
@@ -171,23 +177,23 @@ class Location(ModelSQL, ModelView):
                     product_ids=[Transaction().context['product']],
                     with_childs=True, skip_zero=False).iteritems()
 
-        return dict([(loc,qty) for (loc,prod), qty in pbl])
+        return dict([(loc, qty) for (loc, prod), qty in pbl])
 
-    def view_header_get(self, value, view_type='form'):
+    def get_cost_value(self, ids, name):
         product_obj = Pool().get('product.product')
-        value = super(Location, self).view_header_get(value,
-                view_type=view_type)
-        if (Transaction().context.get('product')
-                and isinstance(Transaction().context['product'], (int, long))):
-            with Transaction().set_context(active_test=False):
-                product_ids = product_obj.search([
-                    ('id', '=', Transaction().context['product']),
-                    ], limit=1)
-            if product_ids:
-                product = product_obj.browse(product_ids[0])
-                return value + ': ' + product.rec_name + \
-                        ' (' + product.default_uom.rec_name + ')'
-        return value
+        trans_context = Transaction().context
+        product_id = trans_context.get('product')
+        if not product_id:
+            return dict((id, None) for id in ids)
+        cost_values, context = {}, {}
+        if 'stock_date_end' in trans_context:
+            context['_datetime'] = trans_context['stock_date_end']
+        with Transaction().set_context(context):
+            product = product_obj.browse(product_id)
+            for location in self.browse(ids):
+                cost_values[location.id] = (Decimal(str(location.quantity))
+                    * product.cost_price)
+        return cost_values
 
     def _set_warehouse_parent(self, locations):
         '''
@@ -267,10 +273,10 @@ class Location(ModelSQL, ModelView):
 
                 wh_default = default.copy()
                 wh_default['type'] = 'view'
-                wh_default['input_location'] = False
-                wh_default['output_location'] = False
-                wh_default['storage_location'] = False
-                wh_default['childs'] = False
+                wh_default['input_location'] = None
+                wh_default['output_location'] = None
+                wh_default['storage_location'] = None
+                wh_default['childs'] = None
 
                 new_id = super(Location, self).copy(location.id,
                         default=wh_default)
@@ -295,8 +301,10 @@ class Location(ModelSQL, ModelView):
                 if location.id in warehouse_locations.values():
                     for field, loc_id in warehouse_locations.iteritems():
                         if loc_id == location.id:
-                            self.write(Transaction().context['cp_warehouse_id'],
-                                    {field: new_id})
+                            self.write(
+                                Transaction().context['cp_warehouse_id'], {
+                                    field: new_id,
+                                    })
 
             res.append(new_id)
 
@@ -319,9 +327,10 @@ class Party(ModelSQL, ModelView):
 Party()
 
 
-class ChooseStockDateInit(ModelView):
-    _name = 'stock.location_stock_date.init'
-    _description = "Compute stock quantities"
+class ProductsByLocationsStart(ModelView):
+    'Products by Locations'
+    _name = 'stock.products_by_locations.start'
+    _description = __doc__
     forecast_date = fields.Date(
         'At Date', help='Allow to compute expected '\
             'stock quantities for this date.\n'\
@@ -332,48 +341,26 @@ class ChooseStockDateInit(ModelView):
         date_obj = Pool().get('ir.date')
         return date_obj.today()
 
-ChooseStockDateInit()
+ProductsByLocationsStart()
 
 
-class OpenProduct(Wizard):
-    'Open Products'
-    _name = 'stock.product.open'
-    states = {
-        'init': {
-            'result': {
-                'type': 'form',
-                'object': 'stock.location_stock_date.init',
-                'state': [
-                    ('end', 'Cancel', 'tryton-cancel'),
-                    ('open', 'Open', 'tryton-ok', True),
-                ],
-            },
-        },
-        'open': {
-            'result': {
-                'type': 'action',
-                'action': '_action_open_product',
-                'state': 'end',
-            },
-        },
-    }
+class ProductsByLocations(Wizard):
+    'Products by Locations'
+    _name = 'stock.products_by_locations'
 
-    def _action_open_product(self, data):
-        model_data_obj = Pool().get('ir.model.data')
-        act_window_obj = Pool().get('ir.action.act_window')
-        act_window_id = model_data_obj.get_id('stock',
-                'act_product_by_location')
-        res = act_window_obj.read(act_window_id)
+    start = StateView('stock.products_by_locations.start',
+        'stock.products_by_locations_start_view_form', [
+            Button('Cancel', 'end', 'tryton-cancel'),
+            Button('Open', 'open', 'tryton-ok', True),
+            ])
+    open = StateAction('stock.act_products_by_locations')
 
+    def do_open(self, session, action):
         context = {}
-        context['locations'] = data['ids']
-        if data['form']['forecast_date']:
-            date = data['form']['forecast_date']
-        else:
-            date = datetime.date.max
+        context['locations'] = Transaction().context.get('active_ids')
+        date = session.start.forecast_date or datetime.date.max
         context['stock_date_end'] = Date(date.year, date.month, date.day)
-        res['pyson_context'] = PYSONEncoder().encode(context)
+        action['pyson_context'] = PYSONEncoder().encode(context)
+        return action, {}
 
-        return res
-
-OpenProduct()
+ProductsByLocations()
