@@ -2,7 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 from functools import reduce
-from trytond.model import ModelView, ModelSQL, fields, OPERATORS
+from trytond.model import ModelView, ModelSQL, fields
 from trytond.backend import TableHandler
 from trytond.pyson import In, Eval, Not, Equal, If, Get, Bool
 from trytond.transaction import Transaction
@@ -20,22 +20,22 @@ class Move(ModelSQL, ModelView):
     _description = __doc__
     _order_name = 'product'
     product = fields.Many2One("product.product", "Product", required=True,
-        select=1, states=STATES,
+        select=True, states=STATES,
         on_change=['product', 'currency', 'uom', 'company',
             'from_location', 'to_location'],
         domain=[('type', '!=', 'service')],
         depends=DEPENDS)
+    product_uom_category = fields.Function(
+        fields.Many2One('product.uom.category', 'Product Uom Category',
+            on_change_with=['product']),
+        'get_product_uom_category')
     uom = fields.Many2One("product.uom", "Uom", required=True, states=STATES,
         domain=[
-            ('category', '=',
-                (Eval('product'), 'product.default_uom.category')),
+            ('category', '=', Eval('product_uom_category')),
             ],
-        context={
-            'category': (Eval('product'), 'product.default_uom.category'),
-            },
         on_change=['product', 'currency', 'uom', 'company',
             'from_location', 'to_location'],
-        depends=['state', 'product'])
+        depends=['state', 'product_uom_category'])
     unit_digits = fields.Function(fields.Integer('Unit Digits',
         on_change_with=['uom']), 'get_unit_digits')
     quantity = fields.Float("Quantity", required=True,
@@ -43,28 +43,28 @@ class Move(ModelSQL, ModelView):
         depends=['state', 'unit_digits'])
     internal_quantity = fields.Float('Internal Quantity', readonly=True,
         required=True)
-    from_location = fields.Many2One("stock.location", "From Location", select=1,
-        required=True, states=STATES, depends=DEPENDS,
+    from_location = fields.Many2One("stock.location", "From Location",
+        select=True, required=True, states=STATES, depends=DEPENDS,
         domain=[('type', 'not in', ('warehouse', 'view'))])
-    to_location = fields.Many2One("stock.location", "To Location", select=1,
+    to_location = fields.Many2One("stock.location", "To Location", select=True,
         required=True, states=STATES, depends=DEPENDS,
         domain=[('type', 'not in', ('warehouse', 'view'))])
     shipment_in = fields.Many2One('stock.shipment.in', 'Supplier Shipment',
         domain=[('company', '=', Eval('company'))], depends=['company'],
-        readonly=True, select=1, ondelete='CASCADE')
+        readonly=True, select=True, ondelete='CASCADE')
     shipment_out = fields.Many2One('stock.shipment.out', 'Customer Shipment',
         domain=[('company', '=', Eval('company'))], depends=['company'],
-        readonly=True, select=1, ondelete='CASCADE')
+        readonly=True, select=True, ondelete='CASCADE')
     shipment_out_return = fields.Many2One('stock.shipment.out.return',
-        'Customer Return Shipment', readonly=True, select=1,
+        'Customer Return Shipment', readonly=True, select=True,
         domain=[('company', '=', Eval('company'))], depends=['company'],
         ondelete='CASCADE')
     shipment_in_return = fields.Many2One('stock.shipment.in.return',
-        'Supplier Return Shipment', readonly=True, select=1,
+        'Supplier Return Shipment', readonly=True, select=True,
         domain=[('company', '=', Eval('company'))], depends=['company'],
         ondelete='CASCADE')
     shipment_internal = fields.Many2One('stock.shipment.internal',
-        'Internal Shipment', readonly=True, select=1, ondelete='CASCADE',
+        'Internal Shipment', readonly=True, select=True, ondelete='CASCADE',
         domain=[('company', '=', Eval('company'))], depends=['company'])
     planned_date = fields.Date("Planned Date", states={
             'readonly': (In(Eval('state'), ['cancel', 'assigned', 'done'])
@@ -73,14 +73,14 @@ class Move(ModelSQL, ModelView):
                 | Eval('shipment_internal'))
             }, depends=['state', 'shipment_in', 'shipment_out',
             'shipment_in_return', 'shipment_out_return', 'shipment_internal'],
-        select=2)
-    effective_date = fields.Date("Effective Date", readonly=True, select=2)
+        select=True)
+    effective_date = fields.Date("Effective Date", readonly=True, select=True)
     state = fields.Selection([
         ('draft', 'Draft'),
         ('assigned', 'Assigned'),
         ('done', 'Done'),
         ('cancel', 'Canceled'),
-        ], 'State', select=1, readonly=True)
+        ], 'State', select=True, readonly=True)
     company = fields.Many2One('company.company', 'Company', required=True,
         states={
             'readonly': Not(Equal(Eval('state'), 'draft')),
@@ -134,7 +134,6 @@ class Move(ModelSQL, ModelView):
                 'Move can be on only one Shipment'),
         ]
         self._constraints += [
-            ('check_product_type', 'service_product'),
             ('check_period_closed', 'period_closed'),
         ]
         self._order[0] = ('id', 'DESC')
@@ -142,8 +141,8 @@ class Move(ModelSQL, ModelView):
             'set_state_draft': 'You can not set state to draft!',
             'set_state_assigned': 'You can not set state to assigned!',
             'set_state_done': 'You can not set state to done!',
-            'del_draft_cancel': 'You can only delete draft or cancelled moves!',
-            'service_product': 'You can not use service products for a move!',
+            'del_draft_cancel': 'You can only delete draft ' \
+                'or cancelled moves!',
             'period_closed': 'You can not modify move in closed period!',
             'modify_assigned_done_cancel': ('You can not modify a move '
                 'in the state: "Assigned", "Done" or "Cancel"'),
@@ -152,7 +151,7 @@ class Move(ModelSQL, ModelView):
     def init(self, module_name):
         cursor = Transaction().cursor
         # Migration from 1.2: packing renamed into shipment
-        table  = TableHandler(cursor, self, module_name)
+        table = TableHandler(cursor, self, module_name)
         table.drop_constraint('check_packing')
         for suffix in ('in', 'out', 'in_return', 'out_return', 'internal'):
             old_column = 'packing_%s' % suffix
@@ -185,86 +184,30 @@ class Move(ModelSQL, ModelView):
             table.not_null_action('internal_quantity', action='add')
 
         # Migration from 1.0 check_packing_in_out has been removed
-        table  = TableHandler(cursor, self, module_name)
+        table = TableHandler(cursor, self, module_name)
         table.drop_constraint('check_packing_in_out')
 
         # Add index on create_date
         table.index_action('create_date', action='add')
 
     def default_planned_date(self):
-        return Transaction().context.get('planned_date') or False
-
-    def default_to_location(self):
-        location_obj = Pool().get('stock.location')
-        party_obj = Pool().get('party.party')
-        res = False
-
-        warehouse = None
-        if Transaction().context.get('warehouse'):
-            warehouse = location_obj.browse(Transaction().context['warehouse'])
-
-        if Transaction().context.get('type', '') == 'inventory_in':
-            if warehouse:
-                res = warehouse.storage_location.id
-        elif Transaction().context.get('type', '') == 'inventory_out':
-            if warehouse:
-                res = warehouse.output_location.id
-        elif Transaction().context.get('type', '') == 'incoming':
-            if warehouse:
-                res = warehouse.input_location.id
-        elif Transaction().context.get('type', '') == 'outgoing':
-            if Transaction().context.get('customer'):
-                customer = party_obj.browse(Transaction().context['customer'])
-                res = customer.customer_location.id
-
-        if Transaction().context.get('to_location'):
-            res = Transaction().context['to_location']
-        return res
-
-    def default_from_location(self):
-        location_obj = Pool().get('stock.location')
-        party_obj = Pool().get('party.party')
-        res = False
-
-        warehouse = None
-        if Transaction().context.get('warehouse'):
-            warehouse = location_obj.browse(Transaction().context['warehouse'])
-
-        if Transaction().context.get('type', '') == 'inventory_in':
-            if warehouse:
-                res = warehouse.input_location.id
-        elif Transaction().context.get('type', '') == 'inventory_out':
-            if warehouse:
-                res = warehouse.storage_location.id
-        elif Transaction().context.get('type', '') == 'outgoing':
-            if warehouse:
-                res = warehouse.output_location.id
-        elif Transaction().context.get('type', '') == 'incoming':
-            if Transaction().context.get('supplier'):
-                supplier = party_obj.browse(Transaction().context['supplier'])
-                res = supplier.supplier_location.id
-            elif Transaction().context.get('customer'):
-                customer = party_obj.browse(Transaction().context['customer'])
-                res = customer.customer_location.id
-
-        if Transaction().context.get('from_location'):
-            res = Transaction().context['from_location']
-        return res
+        return Transaction().context.get('planned_date')
 
     def default_state(self):
         return 'draft'
 
     def default_company(self):
-        return Transaction().context.get('company') or False
+        return Transaction().context.get('company')
 
     def default_currency(self):
         company_obj = Pool().get('company.company')
-        currency_obj = Pool().get('currency.currency')
         company = Transaction().context.get('company')
         if company:
             company = company_obj.browse(company)
             return company.currency.id
-        return False
+
+    def default_unit_digits(self):
+        return 2
 
     def on_change_with_unit_digits(self, vals):
         uom_obj = Pool().get('product.uom')
@@ -295,11 +238,18 @@ class Move(ModelSQL, ModelView):
             res['uom'] = product.default_uom.id
             res['uom.rec_name'] = product.default_uom.rec_name
             res['unit_digits'] = product.default_uom.digits
-            to_location = None
+            from_location, to_location = None, None
+            if vals.get('from_location'):
+                from_location = location_obj.browse(vals['from_location'])
             if vals.get('to_location'):
                 to_location = location_obj.browse(vals['to_location'])
-            if to_location and to_location.type == 'storage':
+            unit_price = None
+            if from_location and from_location.type in ('supplier',
+                    'production'):
                 unit_price = product.cost_price
+            elif to_location and to_location.type == 'customer':
+                unit_price = product.list_price
+            if unit_price:
                 if vals.get('uom') and vals['uom'] != product.default_uom.id:
                     uom = uom_obj.browse(vals['uom'])
                     unit_price = uom_obj.compute_price(product.default_uom,
@@ -312,6 +262,19 @@ class Move(ModelSQL, ModelView):
                 res['unit_price'] = unit_price
         return res
 
+    def on_change_with_product_uom_category(self, values):
+        pool = Pool()
+        product_obj = pool.get('product.product')
+        if values.get('product'):
+            product = product_obj.browse(values['product'])
+            return product.default_uom_category.id
+
+    def get_product_uom_category(self, ids, name):
+        categories = {}
+        for move in self.browse(ids):
+            categories[move.id] = move.product.default_uom_category.id
+        return categories
+
     def on_change_uom(self, vals):
         pool = Pool()
         product_obj = pool.get('product.product')
@@ -342,24 +305,15 @@ class Move(ModelSQL, ModelView):
                 res['unit_price'] = unit_price
         return res
 
-    def default_unit_price_required(self):
-        from_location = self.default_from_location()
-        to_location = self.default_to_location()
-        vals = {
-            'from_location': from_location,
-            'to_location': to_location,
-            }
-        return self.on_change_with_unit_price_required(vals)
-
     def on_change_with_unit_price_required(self, vals):
         location_obj = Pool().get('stock.location')
         if vals.get('from_location'):
             from_location = location_obj.browse(vals['from_location'])
-            if from_location.type == 'supplier':
+            if from_location.type in ('supplier', 'production'):
                 return True
         if vals.get('to_location'):
             to_location = location_obj.browse(vals['to_location'])
-            if to_location.type == 'customer':
+            if to_location.type in ('customer', 'production'):
                 return True
         return False
 
@@ -367,18 +321,12 @@ class Move(ModelSQL, ModelView):
         res = {}
         for move in self.browse(ids):
             res[move.id] = False
-            if move.from_location.type == 'supplier':
+            if move.from_location.type in ('supplier', 'production'):
                 res[move.id] = True
             if move.to_location.type == 'customer':
                 res[move.id] = True
         return res
 
-    def check_product_type(self, ids):
-        for move in self.browse(ids):
-            if move.product.type == 'service':
-                return False
-        return True
-
     def check_period_closed(self, ids):
         period_obj = Pool().get('stock.period')
         period_ids = period_obj.search([
@@ -399,38 +347,13 @@ class Move(ModelSQL, ModelView):
         res = {}
         moves = self.browse(ids)
         for m in moves:
-            res[m.id] = "%s%s %s" % (m.quantity, m.uom.symbol, m.product.rec_name)
+            res[m.id] = ("%s%s %s"
+                % (m.quantity, m.uom.symbol, m.product.rec_name))
         return res
 
     def search_rec_name(self, name, clause):
         return [('product',) + clause[1:]]
 
-    def search(self, args, offset=0, limit=None, order=None, count=False,
-            query_string=False):
-        location_obj = Pool().get('stock.location')
-
-        args = args[:]
-        def process_args(args):
-            i = 0
-            while i < len(args):
-                #add test for xmlrpc that doesn't handle tuple
-                if (isinstance(args[i], tuple) or \
-                        (isinstance(args[i], list) and len(args[i]) > 2 and \
-                        args[i][1] in OPERATORS)) and \
-                        args[i][0] == 'to_location_warehouse':
-                    location_id = False
-                    if args[i][2]:
-                        location = location_obj.browse(args[i][2])
-                        if location.type == 'warehouse':
-                            location_id = location.input_location.id
-                    args[i] = ('to_location', args[i][1], location_id)
-                elif isinstance(args[i], list):
-                    process_args(args[i])
-                i += 1
-        process_args(args)
-        return super(Move, self).search(args, offset=offset, limit=limit,
-                order=order, count=count, query_string=query_string)
-
     def _update_product_cost_price(self, product_id, quantity, uom, unit_price,
             currency, company, date):
         """
@@ -456,6 +379,8 @@ class Move(ModelSQL, ModelView):
 
         if isinstance(uom, (int, long)):
             uom = uom_obj.browse(uom)
+        if isinstance(currency, (int, long)):
+            currency = currency_obj.browse(currency)
         if isinstance(company, (int, long)):
             company = company_obj.browse(company)
 
@@ -489,7 +414,7 @@ class Move(ModelSQL, ModelView):
         else:
             digits = product_template_obj.cost_price.digits
         new_cost_price = new_cost_price.quantize(
-                Decimal(str(10.0**-digits[1])))
+            Decimal(str(10.0 ** -digits[1])))
 
         with Transaction().set_user(0, set_context=True):
             product_obj.write(product.id, {
@@ -502,7 +427,6 @@ class Move(ModelSQL, ModelView):
                 product.default_uom, round=True)
         return internal_quantity
 
-
     def create(self, vals):
         pool = Pool()
         location_obj = pool.get('stock.location')
@@ -517,18 +441,22 @@ class Move(ModelSQL, ModelView):
         product = product_obj.browse(vals['product'])
         if vals.get('state') == 'done':
             vals['effective_date'] = effective_date
+            currency_id = vals.get('currency', self.default_currency())
+            company_id = vals.get('company', self.default_company())
             from_location = location_obj.browse(vals['from_location'])
             to_location = location_obj.browse(vals['to_location'])
-            if from_location.type == 'supplier' \
-                    and product.cost_price_method == 'average':
+            if (from_location.type in ('supplier', 'production')
+                    and to_location.type == 'storage'
+                    and product.cost_price_method == 'average'):
                 self._update_product_cost_price(vals['product'],
                         vals['quantity'], vals['uom'], vals['unit_price'],
-                        vals['currency'], vals['company'], effective_date)
-            if to_location.type == 'supplier' \
-                    and product.cost_price_method == 'average':
+                        currency_id, company_id, effective_date)
+            if (to_location.type == 'supplier'
+                    and from_location.type == 'storage'
+                    and product.cost_price_method == 'average'):
                 self._update_product_cost_price(vals['product'],
                         -vals['quantity'], vals['uom'], vals['unit_price'],
-                        vals['currency'], vals['company'], effective_date)
+                        currency_id, company_id, effective_date)
             if not vals.get('cost_price'):
                 # Re-read product to get the updated cost_price
                 product = product_obj.browse(vals['product'])
@@ -555,16 +483,18 @@ class Move(ModelSQL, ModelView):
         if 'state' in vals:
             for move in moves:
                 if vals['state'] == 'cancel':
-                    vals['effective_date'] = False
-                    if move.from_location.type == 'supplier' \
-                            and move.state != 'cancel' \
-                            and move.product.cost_price_method == 'average':
+                    vals['effective_date'] = None
+                    if (move.from_location.type in ('supplier', 'production')
+                            and move.to_location.type == 'storage'
+                            and move.state != 'cancel'
+                            and move.product.cost_price_method == 'average'):
                         self._update_product_cost_price(move.product.id,
                                 -move.quantity, move.uom, move.unit_price,
                                 move.currency, move.company, today)
-                    if move.to_location.type == 'supplier' \
-                            and move.state != 'cancel' \
-                            and move.product.cost_price_method == 'average':
+                    if (move.to_location.type == 'supplier'
+                            and move.from_location.type == 'storage'
+                            and move.state != 'cancel'
+                            and move.product.cost_price_method == 'average'):
                         self._update_product_cost_price(move.product.id,
                                 move.quantity, move.uom, move.unit_price,
                                 move.currency, move.company, today)
@@ -581,16 +511,18 @@ class Move(ModelSQL, ModelView):
                         self.raise_user_error('set_state_done')
                     vals['effective_date'] = effective_date
 
-                    if move.from_location.type == 'supplier' \
-                            and move.state != 'done' \
-                            and move.product.cost_price_method == 'average':
+                    if (move.from_location.type in ('supplier', 'production')
+                            and move.to_location.type == 'storage'
+                            and move.state != 'done'
+                            and move.product.cost_price_method == 'average'):
                         self._update_product_cost_price(move.product.id,
                                 move.quantity, move.uom, move.unit_price,
                                 move.currency, move.company, effective_date)
-                    if move.to_location.type == 'supplier' \
-                            and move.state != 'done' \
-                            and move.product.cost_price_method == 'average':
-                        self._update_product_cost_price( move.product.id,
+                    if (move.to_location.type == 'supplier'
+                            and move.from_location.type == 'storage'
+                            and move.state != 'done'
+                            and move.product.cost_price_method == 'average'):
+                        self._update_product_cost_price(move.product.id,
                                 -move.quantity, move.uom, move.unit_price,
                                 move.currency, move.company, effective_date)
 
@@ -655,7 +587,7 @@ class Move(ModelSQL, ModelView):
                 to_pick.append((location, available_qty))
                 needed_qty -= available_qty
         # Force assignation for consumables:
-        if move.product.type == "consumable":
+        if move.product.consumable:
             to_pick.append((move.from_location, needed_qty))
             return to_pick
         return to_pick
@@ -725,15 +657,17 @@ class Move(ModelSQL, ModelView):
                     self.write(move.id, values)
                     first = False
                 else:
-                    move_id = self.copy(move.id, default=values)
+                    self.copy(move.id, default=values)
 
                 qty_default_uom = uom_obj.compute_qty(move.uom, qty,
                         move.product.default_uom, round=False)
 
-                pbl[(from_location.id, move.product.id)] = \
-                    pbl.get((from_location.id, move.product.id), 0.0) - qty_default_uom
-                pbl[(to_location.id, move.product.id)]= \
-                    pbl.get((to_location.id, move.product.id), 0.0) + qty_default_uom
+                pbl[(from_location.id, move.product.id)] = (
+                    pbl.get((from_location.id, move.product.id), 0.0)
+                    - qty_default_uom)
+                pbl[(to_location.id, move.product.id)] = (
+                    pbl.get((to_location.id, move.product.id), 0.0)
+                    + qty_default_uom)
         return success
 
 Move()
