@@ -1,21 +1,24 @@
 #!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 
-import sys, os
+import sys
+import os
 DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
     '..', '..', '..', '..', '..', 'trytond')))
 if os.path.isdir(DIR):
     sys.path.insert(0, os.path.dirname(DIR))
 
 import unittest
+import doctest
 import datetime
 from decimal import Decimal
 from dateutil.relativedelta import relativedelta
 from functools import partial
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
+    test_depends
+from trytond.backend.sqlite.database import Database as SQLiteDatabase
 from trytond.transaction import Transaction
 
 
@@ -42,11 +45,17 @@ class StockTestCase(unittest.TestCase):
         '''
         test_view('stock')
 
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
+
     def test0010move_internal_quantity(self):
         '''
         Test Move.internal_quantity.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             category_id = self.category.create({
                 'name': 'Test Move.internal_quantity',
                 })
@@ -54,7 +63,9 @@ class StockTestCase(unittest.TestCase):
             g_id, = self.uom.search([('name', '=', 'Gram')])
             product_id = self.product.create({
                 'name': 'Test Move.internal_quantity',
-                'type': 'stockable',
+                'type': 'goods',
+                'list_price': Decimal(0),
+                'cost_price': Decimal(0),
                 'category': category_id,
                 'cost_price_method': 'fixed',
                 'default_uom': kg_id,
@@ -72,7 +83,7 @@ class StockTestCase(unittest.TestCase):
             tests = [
                 (kg_id, 10, 10),
                 (g_id, 100, 0.1),
-                (g_id, 1, 0), # rounded
+                (g_id, 1, 0),  # rounded
             ]
             for uom_id, quantity, internal_quantity in tests:
                 move_id = self.move.create({
@@ -102,17 +113,21 @@ class StockTestCase(unittest.TestCase):
         '''
         Test products_by_location.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             category_id = self.category.create({
                 'name': 'Test products_by_location',
                 })
-            unit_id, = self.uom.search([('name', '=', 'Unit')])
+            kg_id, = self.uom.search([('name', '=', 'Kilogram')])
+            g_id, = self.uom.search([('name', '=', 'Gram')])
             product_id = self.product.create({
                 'name': 'Test products_by_location',
-                'type': 'stockable',
+                'type': 'goods',
+                'list_price': Decimal(0),
+                'cost_price': Decimal(0),
                 'category': category_id,
                 'cost_price_method': 'fixed',
-                'default_uom': unit_id,
+                'default_uom': kg_id,
                 })
             supplier_id, = self.location.search([('code', '=', 'SUP')])
             customer_id, = self.location.search([('code', '=', 'CUS')])
@@ -129,7 +144,7 @@ class StockTestCase(unittest.TestCase):
 
             self.move.create({
                 'product': product_id,
-                'uom': unit_id,
+                'uom': kg_id,
                 'quantity': 5,
                 'from_location': supplier_id,
                 'to_location': storage_id,
@@ -142,7 +157,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': unit_id,
+                'uom': kg_id,
                 'quantity': 1,
                 'from_location': supplier_id,
                 'to_location': storage_id,
@@ -154,7 +169,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': unit_id,
+                'uom': kg_id,
                 'quantity': 1,
                 'from_location': storage_id,
                 'to_location': customer_id,
@@ -167,7 +182,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': unit_id,
+                'uom': kg_id,
                 'quantity': 1,
                 'from_location': storage_id,
                 'to_location': customer_id,
@@ -179,7 +194,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': unit_id,
+                'uom': kg_id,
                 'quantity': 2,
                 'from_location': storage_id,
                 'to_location': customer_id,
@@ -191,7 +206,7 @@ class StockTestCase(unittest.TestCase):
                 })
             self.move.create({
                 'product': product_id,
-                'uom': unit_id,
+                'uom': kg_id,
                 'quantity': 5,
                 'from_location': supplier_id,
                 'to_location': storage_id,
@@ -283,29 +298,48 @@ class StockTestCase(unittest.TestCase):
                 today + relativedelta(days=-3),
                 today + relativedelta(days=-2),
             ]
+
+            self.move.create({
+                'product': product_id,
+                'uom': g_id,
+                'quantity': 1,
+                'from_location': supplier_id,
+                'to_location': storage_id,
+                'planned_date': today + relativedelta(days=-5),
+                'effective_date': today + relativedelta(days=-5),
+                'state': 'done',
+                'company': company_id,
+                'unit_price': Decimal('1'),
+                'currency': currency_id,
+                })
+            # Nothing should change when adding a small quantity
+            test_products_by_location()
+
             for period_date in periods:
                 period_id = self.period.create({
                     'date': period_date,
                     'company': company_id,
                 })
-                self.period.button_close([period_id])
+                self.period.close([period_id])
                 test_products_by_location()
 
     def test0030period(self):
         '''
         Test period.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             category_id = self.category.create({
                 'name': 'Test period',
                 })
             unit_id, = self.uom.search([('name', '=', 'Unit')])
             product_id = self.product.create({
                 'name': 'Test period',
-                'type': 'stockable',
+                'type': 'goods',
                 'category': category_id,
                 'cost_price_method': 'fixed',
                 'default_uom': unit_id,
+                'list_price': Decimal(0),
+                'cost_price': Decimal(0),
                 })
             supplier_id, = self.location.search([('code', '=', 'SUP')])
             customer_id, = self.location.search([('code', '=', 'CUS')])
@@ -377,7 +411,7 @@ class StockTestCase(unittest.TestCase):
                     'date': today + relativedelta(days=days),
                     'company': company_id,
                 })
-                self.period.button_close([period_id])
+                self.period.close([period_id])
 
                 period = self.period.read(period_id, ['state', 'caches'])
                 self.assertEqual(period['state'], 'closed')
@@ -425,13 +459,26 @@ class StockTestCase(unittest.TestCase):
                 'date': today,
                 'company': company_id,
             })
-            self.assertRaises(Exception, self.period.button_close, [period_id])
+            self.assertRaises(Exception, self.period.close, [period_id])
 
             period_id = self.period.create({
                 'date': today + relativedelta(days=1),
                 'company': company_id,
             })
-            self.assertRaises(Exception, self.period.button_close, [period_id])
+            self.assertRaises(Exception, self.period.close, [period_id])
+
+
+def doctest_dropdb(test):
+    '''
+    Remove sqlite memory database
+    '''
+    database = SQLiteDatabase().connect()
+    cursor = database.cursor(autocommit=True)
+    try:
+        database.drop(cursor, ':memory:')
+        cursor.commit()
+    finally:
+        cursor.close()
 
 
 def suite():
@@ -441,6 +488,10 @@ def suite():
         if test not in suite:
             suite.addTest(test)
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(StockTestCase))
+    suite.addTests(doctest.DocFileSuite('scenario_stock_shipment_out.rst',
+        setUp=doctest_dropdb, tearDown=doctest_dropdb, encoding='utf-8',
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+
     return suite
 
 if __name__ == '__main__':
